from distutils.core import setup

setup(
    name='twodarr',
    packages=['twodarr'],
    version='1.0',
    license='MIT',
    author='Justin Riegerix',
    author_email='1305jjr@gmail.com',
    url='https://github.com/ConjunctionJustin/twodarr/tree/main',
    download_url='https://github.com/ConjunctionJustin/twodarr/archive/refs/tags/v1.0.tar.gz',
    description=open('README.txt').read()
)